==> youtube_player_iframe_web-2.0.0.tar.gz: lib/src/web_youtube_player_iframe_platform.dart <==
// Copyright 2022 Sarbagya Dhaubanjar. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';
import 'package:youtube_player_iframe_web/src/web_youtube_player_iframe_controller.dart';

/// An implementation of [WebViewPlatform] using Flutter for Web API.
class WebYoutubePlayerIframePlatform extends WebViewPlatform {
  @override
  PlatformWebViewController createPlatformWebViewController(
    PlatformWebViewControllerCreationParams params,
  ) {
    return WebYoutubePlayerIframeController(params);
  }

  @override
  PlatformWebViewWidget createPlatformWebViewWidget(
    PlatformWebViewWidgetCreationParams params,
  ) {
    return YoutubePlayerIframeWeb(params);
  }

  @override
  PlatformNavigationDelegate createPlatformNavigationDelegate(
    PlatformNavigationDelegateCreationParams params,
  ) {
    return WebNavigationDelegate(params);
  }

  /// Gets called when the plugin is registered.
  static void registerWith(Registrar registrar) {}
}

/// An implementation of [PlatformNavigationDelegate] using Flutter for Web API.
class WebNavigationDelegate extends PlatformNavigationDelegate {
  /// Creates a new [WebNavigationDelegate] instance.
  WebNavigationDelegate(PlatformNavigationDelegateCreationParams params)
      : super.implementation(params);

  @override
  Future<void> setOnNavigationRequest(
    NavigationRequestCallback onNavigationRequest,
  ) async {}

  @override
  Future<void> setOnWebResourceError(
    WebResourceErrorCallback onWebResourceError,
  ) async {}
}

==> youtube_player_iframe_web-2.0.1.tar.gz: lib/src/web_youtube_player_iframe_platform.dart <==
// Copyright 2022 Sarbagya Dhaubanjar. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';
import 'package:youtube_player_iframe_web/src/web_youtube_player_iframe_controller.dart';

/// An implementation of [WebViewPlatform] using Flutter for Web API.
class WebYoutubePlayerIframePlatform extends WebViewPlatform {
  @override
  PlatformWebViewController createPlatformWebViewController(
    PlatformWebViewControllerCreationParams params,
  ) {
    return WebYoutubePlayerIframeController(params);
  }

  @override
  PlatformWebViewWidget createPlatformWebViewWidget(
    PlatformWebViewWidgetCreationParams params,
  ) {
    return YoutubePlayerIframeWeb(params);
  }

  @override
  PlatformNavigationDelegate createPlatformNavigationDelegate(
    PlatformNavigationDelegateCreationParams params,
  ) {
    return WebNavigationDelegate(params);
  }

  /// Gets called when the plugin is registered.
  static void registerWith(Registrar registrar) {
    WebViewPlatform.instance = WebYoutubePlayerIframePlatform();
  }
}

/// An implementation of [PlatformNavigationDelegate] using Flutter for Web API.
class WebNavigationDelegate extends PlatformNavigationDelegate {
  /// Creates a new [WebNavigationDelegate] instance.
  WebNavigationDelegate(PlatformNavigationDelegateCreationParams params)
      : super.implementation(params);

  @override
  Future<void> setOnNavigationRequest(
    NavigationRequestCallback onNavigationRequest,
  ) async {}

  @override
  Future<void> setOnWebResourceError(
    WebResourceErrorCallback onWebResourceError,
  ) async {}
}
